@@ -25,15 +25,11 @@
 #include "gmetadata.h"
 #include "gcmd.h"
 #include "gdnd.h"
-#include "gmount.h"
 #include "gpopup.h"
-#include "gprint.h"
 #include "gscreen.h"
 #include "../vfs/vfs.h"
 #include "main.h"
-
-/* Name of the user's desktop directory (i.e. ~/desktop) */
-#define DESKTOP_DIR_NAME ".gnome-desktop"
+#include "gmount.h"
 
 
 struct layout_slot {
@@ -2044,7 +2040,8 @@ create_layout_info (void)
 	layout_slots = g_new0 (struct layout_slot, layout_cols * layout_rows);
 }
 
-/* Check that the user's desktop directory exists, and if not, create the
+/*
+ * Check that the user's desktop directory exists, and if not, create the
  * default desktop setup.
  */
 static void
@@ -2074,7 +2071,7 @@ create_desktop_dir (void)
 		}
 		g_free (home_link_name);
 
-		gmount_setup_devices ();
+		gdesktop_init ();
 	}
 }
 
@@ -2378,8 +2375,9 @@ void
 desktop_rescan_devices (void)
 {
 	desktop_cleanup_devices ();
-	gmount_setup_devices ();
-	gprint_setup_devices ();
+
+	gdesktop_init ();
+
 	desktop_reload_icons (FALSE, 0, 0);
 }
 
@@ -2396,10 +2394,31 @@ handle_rescan_desktop (GtkWidget *widget, gpointer data)
 {
 	desktop_reload_icons (FALSE, 0, 0);
 }
+static void
+set_background_image (GtkWidget *widget, gpointer data)
+{
+	gchar *bg_capplet;
+	gchar *argv[1];
+	bg_capplet = gnome_is_program_in_path ("background-properties-capplet");
+	if (bg_capplet) {
+		argv[0] = bg_capplet;
+		gnome_execute_async (bg_capplet, 1, argv);
+		g_free (bg_capplet);
+	} else {
+		GtkWidget *msg_box;
+		msg_box = gnome_message_box_new (_("Unable to locate the file:\nbackground-properties-capplet\n"
+						   "in your path.\n\nWe are unable to set the background."),
+						 GNOME_MESSAGE_BOX_WARNING,
+						 GNOME_STOCK_BUTTON_OK,
+						 NULL);
+		gnome_dialog_run (msg_box);
+	}
+}
 static GnomeUIInfo gnome_panel_new_menu [] = {
-	 GNOMEUIINFO_ITEM_NONE(N_("_Terminal"), N_("Launch a new terminal in the current directory"), gnome_open_terminal),
+	GNOMEUIINFO_ITEM_NONE(N_("_Terminal"), N_("Launch a new terminal in the current directory"), gnome_open_terminal),
 	/* If this ever changes, make sure you update create_new_menu accordingly. */
 	GNOMEUIINFO_ITEM_NONE( N_("_Directory..."), N_("Creates a new directory"), gnome_mkdir_cmd ),
+	GNOMEUIINFO_ITEM_NONE( N_("_Launcher..."), N_("Creates a new launcher"), gnome_new_launcher ),
 	GNOMEUIINFO_END
 };
 
@@ -2410,8 +2429,9 @@ GnomeUIInfo desktop_popup_items[] = {
 	GNOMEUIINFO_ITEM_NONE (N_("Arrange Icons"), NULL, handle_arrange_icons),
 	GNOMEUIINFO_ITEM_NONE (N_("Create New Window"), NULL, handle_new_window),
 	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_ITEM_NONE (N_("Rescan Mountable Devices"), NULL, handle_rescan_devices),
+	GNOMEUIINFO_ITEM_NONE (N_("Recreate Desktop Shortcuts"), NULL, handle_rescan_devices),
 	GNOMEUIINFO_ITEM_NONE (N_("Rescan Desktop"), NULL, handle_rescan_desktop),
+	GNOMEUIINFO_ITEM_NONE (N_("Configure Background Image"), NULL, set_background_image),
 	GNOMEUIINFO_END
 };
 
@@ -2904,3 +2924,24 @@ desktop_destroy (void)
 	XDeleteProperty (GDK_DISPLAY (), GDK_ROOT_WINDOW (), gdk_atom_intern ("XdndProxy", FALSE));
 }
 
+void
+desktop_create_url (const char *filename, const char *title, const char *url, const char *icon)
+{
+	FILE *f;
+
+	f = fopen (filename, "w");
+	if (f) {
+		
+		fprintf (f, "URL: %s\n", url);
+		fclose (f);
+		
+		gnome_metadata_set (filename, "desktop-url",
+				    strlen (url) + 1, url);
+		gnome_metadata_set (filename, "icon-caption",
+				    strlen (title) + 1, title);
+		
+		gnome_metadata_set (filename, "icon-filename", strlen (icon) + 1, icon);
+	}
+}
+
+
