@@ -113,6 +113,17 @@ panel_file_list_set_type_bitmap (GtkCList *cl, int row, int column, int color, f
 	}
 }
 
+static void
+panel_cancel_drag_scroll (WPanel *panel)
+{
+	g_return_if_fail (panel != NULL);
+	
+	if (panel->timer_id != -1){
+		gtk_timeout_remove (panel->timer_id);
+		panel->timer_id = -1;
+	}
+}
+
 /*
  * Sets the color attributes for a given row.
  */
@@ -605,10 +616,7 @@ typedef gboolean (*scroll_fn)(gpointer data);
 static gboolean
 panel_setup_drag_scroll (WPanel *panel, int x, int y, desirable_fn desirable, scroll_fn scroll)
 {
-	if (panel->timer_id != -1){
-		gtk_timeout_remove (panel->timer_id);
-		panel->timer_id = -1;
-	}
+	panel_cancel_drag_scroll (panel);
 
 	panel->drag_motion_x = x;
 	panel->drag_motion_y = y;
@@ -728,6 +736,7 @@ panel_drag_data_get (GtkWidget        *widget,
 	char *data;
 	GList *files;
 
+	panel_cancel_drag_scroll (panel);
 	data = panel_build_selected_file_list (panel, &len);
 
 	switch (info){
@@ -1005,6 +1014,7 @@ panel_drag_begin (GtkWidget *widget, GdkDragContext *context, WPanel *panel)
 static void
 panel_drag_end (GtkWidget *widget, GdkDragContext *context, WPanel *panel)
 {
+	panel_cancel_drag_scroll (panel);
 	panel->dragging = 0;
 }
 
@@ -1164,10 +1174,7 @@ panel_clist_drag_leave (GtkWidget *widget, GdkDragContext *ctx, guint time, void
 {
 	WPanel *panel = data;
 
-	if (panel->timer_id != -1){
-		gtk_timeout_remove (panel->timer_id);
-		panel->timer_id = -1;
-	}
+	panel_cancel_drag_scroll (panel);
 }
 
 /**
@@ -1280,10 +1287,7 @@ panel_icon_list_drag_leave (GtkWidget *widget, GdkDragContext *ctx, guint time,
 {
 	WPanel *panel = data;
 
-	if (panel->timer_id != -1){
-		gtk_timeout_remove (panel->timer_id);
-		panel->timer_id = -1;
-	}
+	panel_cancel_drag_scroll (panel);
 }
 
 /*
@@ -2044,6 +2048,8 @@ panel_tree_check_auto_expand (WPanel *panel, GtkCTreeNode *current)
 	 * so that the "current" stays the same place on the
 	 * screen
 	 */
+#if 0
+	/* This behaviour is confusing --jrb and quartic (and MS, apparently)*/
 	if (tmp_list) {
 		if (current) {
 			row = g_list_position (clist->row_list, (GList *)current);
@@ -2074,6 +2080,7 @@ panel_tree_check_auto_expand (WPanel *panel, GtkCTreeNode *current)
 		free_list->prev = NULL;
 		g_list_free (free_list);
 	}
+#endif
 }
 
 /**
@@ -2130,9 +2137,11 @@ panel_tree_drag_motion (GtkWidget *widget, GdkDragContext *ctx, int x, int y, gu
 		GtkCTreeNode *current;
 		current = gtk_ctree_node_nth (GTK_CTREE (widget), row);
 		panel_tree_check_auto_expand (panel, current);
+		GTK_DTREE (widget)->internal = TRUE;
+		gtk_clist_select_row (GTK_CLIST (widget), row, 0);
+		GTK_DTREE (widget)->internal = FALSE;
 	} else
 		panel_tree_check_auto_expand (panel, NULL);
-		
 	panel->timer_id = gtk_timeout_add (400, tree_drag_open_directory, data);
 	return TRUE;
 }
