@@ -76,7 +76,7 @@
 #include "user.h"		/* expand_format */
 #include "../vfs/vfs.h"
 
-/* "$Id: util.c,v 1.21 1999/03/10 21:56:21 norbert Exp $" */
+/* "$Id: util.c,v 1.22 1999/03/18 13:40:26 timur Exp $" */
 
 char app_text [] = "Midnight-Commander";
 
@@ -174,23 +174,29 @@ name_quote (const char *s, int quote_percent)
 	    case '\r':
 	    case '\n':
 	    case '\t':
-	    case '$':
+	    case '"':
+	    case ':':
+	    case ';':
+	    case ' ':
 	    case '?':
-	    case '*':
-	    case '(':
-	    case ')':
+	    case '|':
 	    case '[':
 	    case ']':
 	    case '{':
 	    case '}':
 	    case '<':
 	    case '>':
-	    case '"':
-	    case '!':
-	    case '&':
-	    case '#':
 	    case '`':
-	    case ' ':
+	    case '~':
+	    case '!':
+	    case '@':
+	    case '#':
+	    case '$':
+	    case '^':
+	    case '&':
+	    case '*':
+	    case '(':
+	    case ')':
 		*d++ = '\\';
 	}
 	*d = *s;
