@@ -28,7 +28,7 @@
 
 /* }}} */
 
-/*  [] = "$Id: wtools.c,v 1.16 1999/03/16 20:46:57 unammx Exp $" */
+/*  [] = "$Id: wtools.c,v 1.17 1999/03/24 12:17:08 unammx Exp $" */
 
 #include <config.h>
 #include <string.h>
@@ -581,8 +581,10 @@ char *real_input_dialog_help (char *header, char *text, char *help, char *def_te
 
     len = max (strlen (header), msglen (text, &lines)) + 4;
     len = max (len, 64);
-
-    if (strncmp (text, _("Password:"), strlen (_("Password"))) == 0){
+    
+    /* Translators should take care as "Password" or its translations
+    are used to identify password boxes and hide characters with "*" */
+    if (strncmp (text, _("Password:"), strlen (_("Password:"))-1) == 0){
 	quick_widgets [INPUT_INDEX].value = 1;
 	tk_name[3]=0;
     } else {
